#
# spec file for package perl-Data-Dump-Streamer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Data-Dump-Streamer
Name:           perl-Data-Dump-Streamer
Version:        2.42
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Accurately serialize a data structure as Perl code
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(B::Utils)
BuildRequires:  perl(ExtUtils::CBuilder)
BuildRequires:  perl(ExtUtils::Depends)
BuildRequires:  perl(Module::Build)
Requires:       perl(B::Utils)
Recommends:     perl(Algorithm::Diff)
Recommends:     perl(Compress::Zlib)
Recommends:     perl(Cpanel::JSON::XS)
Recommends:     perl(PadWalker) >= 0.99
%{perl_requires}

%description
Given a list of scalars or reference variables, writes out their contents
in perl syntax. The references can also be objects. The contents of each
variable is output using the least number of Perl statements as convenient,
usually only one. Self-referential structures, closures, and objects are
output correctly.

The return value can be evaled to get back an identical copy of the
original reference structure. In some cases this may require the use of
utility subs that Data::Dump::Streamer will optionally export.

This module is very similar in concept to the core module Data::Dumper,
with the major differences being that this module is designed to output to
a stream instead of constructing its output in memory (trading speed for
memory), and that the traversal over the data structure is effectively
breadth first versus the depth first traversal done by the others.

In fact the data structure is scanned twice, first in breadth first mode to
perform structural analysis, and then in depth first mode to actually
produce the output, but obeying the depth relationships of the first pass.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor optimize="%{optflags}"
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Wed Feb 22 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.42
  see /usr/share/doc/packages/perl-Data-Dump-Streamer/Changes
  2.42
  Perltidy source to my preferred format. Fixed issues serializing
  the global stash. Added test to detect if serializing the global
  stash breaks anything.
* Sat Jan 28 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.41
  see /usr/share/doc/packages/perl-Data-Dump-Streamer/Changes
  2.41
  Merged in all the open PR's. Some MUCH much later than I originally
  intended to. Humble apologies to those who contributed fixes for that.
  Switch from JSON::XS to Cpanel::JSON::XS as an optional test prereq.
  Thanks to Karen Etheridge, Kent Frederic and Michael Schwern.
* Wed Aug 31 2016 coolo@suse.com
- updated to 2.40
  see /usr/share/doc/packages/perl-Data-Dump-Streamer/Changes
  2.40
  Fixup issues with JSON and with non-Padwalker builds (thanks to FC)
  various other tweaks and cleanups to build on newer Perls. Updated
  meta files, etc.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 2.39:
  + No changelog available.
- Add perl(PadWalker) BuildRequires: needed to pass the test suite.
* Sat Jul 19 2014 coolo@suse.com
- updated to 2.38
  Only github log
* Mon Feb 10 2014 coolo@suse.com
- updated to 2.37
  Various changes. See github log for changes.
- fixes build in factory
* Fri Oct  4 2013 coolo@suse.com
- updated to 2.36
  Should work on 5.18 now.
- obsoleting rt_79127.diff and rt_82958.diff
* Wed Jun 26 2013 coolo@suse.com
- add rt_79127.diff and rt_82958.diff from rt.cpan.org
  to fix build with perl 5.18
* Mon Jun 10 2013 coolo@suse.com
- updated to 2.34
  Administrative release to eliminate build dependency on module
  used only for testing.
* Wed May 30 2012 coolo@suse.com
- updated to 2.33
  Caught up with various RT reports, and fixed a bunch of them.
  [RT#74198] fixed dumps containing read-only objects (obtained via JSON::XS)
  [RT#74198], Fixed stringification of code compiled under strict in later
  perls. Thanks to Father Chrysotomos for the patch and nudge.
  Also eliminated a false-fail prone test which was actually pretty useless,
  which should close several tickets which I wont bother to list.
  This release also is the first from the new git repository at
  https://github.com/demerphq/Data-Dump-Streamer
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Apr  5 2011 coolo@novell.com
- updated to 2.32
  Disable overloading in a <=5.8.8 safe way [RT #53700]
  2.31
  React to Strawberry perl $. strangeness [RT #58528]
  2.29
  Add .answer to .gitignore
  Update t/madness for perl-5.6
  Syntax fix print() for perl-5.6
  Correct ${^WARNING_BITS} in t/madness.t for perl-5.8.7 and earlier
  2.28
  Strip illegal regexp modifiers [RT #65355]
  Update file permissions
  2.27
  Test for new regexp /u flag [RT #65339]
  Import less private functions
  Removed obsolete svn version info
  2.26
  Keep a glob reference open while inspecting through it with B. [RT #65272]
  2.25 (2011-01-24)
  Oops, add ppport.h to the packaged distribution
  2.24 (2011-01-23)
  Fix weakref breakage from perl-5648c0a. [RT #62605]
  Add ppport.h
  Add .gitignore
  2.23 (2011-01-18)
  Fix DumpLex for bug #44621
* Thu Jul 15 2010 pascal.bleser@opensuse.org
- update to 2.22:
  * Build.PL fixed to accept DDS and NODDS again
* Mon Jun 21 2010 pascal.bleser@opensuse.org
- update to 2.21:
  * resynchronize internal VERSION declarations
- skipped v2.20 because it some of the build code was truncating it to v2.2 and breaking
- changes from 2.19:
  * tweak t/madness.t to deal with how perl-5.8.[0-8] deparses the pragma `use warnings' differently
* Sat Jun 12 2010 pascal.bleser@opensuse.org
- update to 2.18
* Tue May 11 2010 pascal.bleser@opensuse.org
- initial package (2.13)
